#
# spec file for package uranium
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define UM_1_minor 6

Name:           uranium
%define sversion        4.13.1
Version:        4.13.1
Release:        2.4
Summary:        Python framework for Desktop applications
License:        LGPL-3.0-only
Group:          Development/Languages/Python
URL:            https://github.com/Ultimaker/Uranium
Source0:        https://github.com/Ultimaker/Uranium/archive/%{sversion}.tar.gz#/%{name}-%{version}.tar.gz
# X-OPENSUSE-FIX fix cmake install directory.
Patch1:         fix-cmake-install.patch
BuildRequires:  cmake
#BuildRequires:  gcc-c++
# for tests:
BuildRequires:  python3-Arcus >= %{version}
BuildRequires:  python3-Twisted
BuildRequires:  python3-cryptography
BuildRequires:  python3-numpy
BuildRequires:  python3-pip
BuildRequires:  python3-pytest
BuildRequires:  python3-qt5
BuildRequires:  python3-scipy
BuildRequires:  python3-shapely
# END for tests
%if 0%{?suse_version} >= 1550
# Automatic provides are not generated in Leap 15.x
Requires:       %{python3_dist arcus}
Requires:       %{python3_dist cryptography}
Requires:       %{python3_dist shapely}
%else
Requires:       python3-Arcus
Requires:       python3-cryptography
Requires:       python3-Shapely
%endif
Recommends:     python3-numpy-stl
BuildArch:      noarch
# No 32bit support in cura-engine anymore
ExcludeArch:    %ix86 %arm
# Registered in UM/Qt/Bindings/Bindings.py
Provides:       qt5qmlimport(UM.1) = %{UM_1_minor}

%description
A Python framework for building Desktop applications.

%prep
%setup -q -n Uranium-%sversion
%patch1 -p1

# Sanity check
UM_1_LARGEST_MINOR=$(\
  sed -e '/qmlRegister\(Singleton\)\?Type/ { s/.*"UM",.*1, *\([0-9]\+\).*/\1/ p } ; d' \
  UM/Qt/Bindings/Bindings.py | sort -g -u | tail -n 1 )
test "${UM_1_LARGEST_MINOR}" -eq "%{UM_1_minor}" || exit 1

%build
# Hack, remove LIB_SUFFIX for 64bit, which is correct as uranium is pure python (i.e. noarch)
%cmake -DLIB_SUFFIX="" \
       -DCMAKE_MODULES_INSTALL_DIR=%{_datadir}/cmake/Modules
%cmake_build

%install
pushd build
%make_install
# uranium uses i18n instead of locale for the path to translation files,
# thus we cannot use %%find_lang
popd
find %{buildroot}%{_datadir}/%{name} -name %{name}.po* -delete
echo '%defattr(644,root,root,755)' > %{name}.lang
find %{buildroot}%{_datadir}/%{name} -name %{name}.mo | sed '
  s:'%{buildroot}'::; s:\(.*/i18n/\)\([^/]\+\)\(.*mo\):%lang(\2) \1\2\3:' \
  >> %{name}.lang
find %{buildroot}%{_datadir}/%{name} -type d -path \*i18n\* | sed '
  s:'%{buildroot}'::; s:\(.*/i18n.*\):%dir \1:' \
  >> %{name}.lang

%check
%{__python3} -m pip freeze
# TestHttpRequestManager has threading issues, see https://github.com/Ultimaker/Uranium/issues/594
%{__python3} -m pytest -v -k 'not TestHttpRequestManager.py'

%files -f %{name}.lang
%license LICENSE
%doc docs README.md
%{_prefix}/lib/uranium
%{python3_sitelib}/UM
%{_datadir}/uranium
%{_datadir}/cmake/Modules/UraniumTranslationTools.cmake

%changelog
* Tue Jun 21 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use versioned python dist provides to enforce a consistent set
  of installed dependies on change of default python version.
* Sun Feb  6 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 4.13.1
  * https://github.com/Ultimaker/Cura/releases/tag/4.13.1
* Thu Jan 27 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- update to 4.13.0
  * https://github.com/Ultimaker/Cura/releases/tag/4.13.0
* Mon Apr 26 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 4.9.0
  * https://github.com/Ultimaker/Cura/releases/tag/4.9
- Bump "UM" QML version to 1.6
* Sat Jan 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add compatibility with qml-autoreqprov
* Sat Nov 21 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Remove unused gcc and python3-devel build dependencies, replace
  libArcus-devel by python3-Arcus.
* Tue Nov 10 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 4.8.0
  * https://github.com/Ultimaker/Cura/releases/tag/4.8
* Tue Sep 15 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.7.1
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/4.7.1
  * https://github.com/Ultimaker/Cura/releases/tag/4.7.0
  * https://github.com/Ultimaker/Cura/releases/tag/4.6.2
- Drop obsolete
  0001-Handle-indexing-on-Python-3.8-AST-string-constants-c.patch
* Sun Jun  7 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.6.1
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/4.6.1
  * https://github.com/Ultimaker/Cura/releases/tag/4.6.0
  * https://github.com/Ultimaker/Cura/releases/tag/4.5.0
- Rebase fix-cmake-install.patch
- Drop obsolete Check-validity-of-polygon.patch
- Fix AST parsing for Python 3.8, add
  0001-Handle-indexing-on-Python-3.8-AST-string-constants-c.patch
* Tue Feb 18 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix crash with libGeos 3.8.0, https://github.com/Ultimaker/Cura/issues/6771
  Check-validity-of-polygon.patch
* Thu Jan  2 2020 Adrian Schröter <adrian@suse.de>
- update to version 4.4.1
  * version update only
* Fri Nov 22 2019 Adrian Schröter <adrian@suse.de>
- update to version 4.4.0
  (not tagged, assumed to be 80b34433f026cb1f0a084d8b1ca00f633692ad92)
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/v4.4.0
* Fri Sep 27 2019 Adrian Schröter <adrian@suse.de>
- update to version 4.3.0
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/4.3.0
* Mon Aug 12 2019 Adrian Schröter <adrian@suse.de>
- update to version 4.2.0
  * https://ultimaker.com/en/blog/52912-ultimaker-cura-42-first-choice-for-3d-printing-professionals-worldwide
* Thu Jun 13 2019 Adrian Schröter <adrian@suse.de>
- update to version 4.1.0
  * https://ultimaker.com/en/products/ultimaker-cura-software/release-notes
  * fix-cmake-install.patch added
- enable test cases
* Thu Jan 17 2019 Adrian Schröter <adrian@suse.de>
- add recommends to numpy-stl
* Fri Nov 16 2018 Adrian Schröter <adrian@suse.de>
- update to version 3.6.0
  https://ultimaker.com/en/products/ultimaker-cura-software/release-notes
* Wed Oct 17 2018 Adrian Schröter <adrian@suse.de>
- update to version 3.5.1
  https://ultimaker.com/en/products/ultimaker-cura-software/release-notes
* Thu Jul 26 2018 jengelh@inai.de
- Fix RPM group.
* Mon Jul 16 2018 adrian@suse.de
- update to version 3.4.1
  https://ultimaker.com/en/products/ultimaker-cura-software/release-notes
* Mon Jul  9 2018 adrian@suse.de
- update to version 3.3.0
  * No release notes
* Sat Jan 27 2018 stefan.bruens@rwth-aachen.de
- Fix incorrect install path, make package noarch again
* Thu Jan 25 2018 adrian@suse.de
- update to 3.1.0
* Fri Dec  8 2017 stefan.bruens@rwth-aachen.de
- Fix License, Cura 3.0 and libraries are LGPL-3.0 now
* Thu Dec  7 2017 stefan.bruens@rwth-aachen.de
- Cleanup spec file
- Build as noarch
* Fri Nov  3 2017 adrian@suse.de
- update to version 3.0.3
* Mon Sep  4 2017 adrian@suse.de
- update to version 2.7.0
* Mon Jun 26 2017 adrian@suse.de
- stable 2.6.0
* Mon Jun 20 2016 adrian@suse.de
- initial package
